@@ -171,6 +171,18 @@ class RegexFormatter(string.Formatter):
     >>> regex_formatter.extract_values('{field_one:5d}_{field_two}', '12345_sometext')
     {'field_one': '12345', 'field_two': 'sometext'}
 
+    Note that the regular expressions generated by this class are specially
+    generated to reduce "greediness" of the matches found. For ambiguous
+    patterns where a single field could match shorter or longer portions of
+    the provided string, this class will prefer the shorter version of the
+    string in order to make the rest of the pattern match. For example:
+
+    >>> regex_formatter.extract_values('{field_one}_{field_two}', 'abc_def_ghi')
+    {'field_one': 'abc', 'field_two': 'def_ghi'}
+
+    Note how `field_one` could have matched "abc_def", but the lower
+    greediness of this parser caused it to only match against "abc".
+
     """
 
     # special string to mark a parameter not being specified
@@ -255,7 +267,7 @@ class RegexFormatter(string.Formatter):
             raise ValueError("Invalid format specification: '{}'".format(format_spec))
         final_regex = char_type
         if ftype in allow_multiple and (not width or width == '0'):
-            final_regex += r'*'
+            final_regex += r'*?'
         elif width and width != '0':
             if not fill:
                 # we know we have exactly this many characters
@@ -266,7 +278,7 @@ class RegexFormatter(string.Formatter):
                 # later during type conversion.
                 final_regex = r'.{{{}}}'.format(int(width))
             elif ftype in allow_multiple:
-                final_regex += r'*'
+                final_regex += r'*?'
 
         return r'(?P<{}>{})'.format(field_name, final_regex)
 
@@ -284,7 +296,7 @@ class RegexFormatter(string.Formatter):
 
         # Replace format spec with glob patterns (*, ?, etc)
         if not format_spec:
-            return r'(?P<{}>.*)'.format(field_name)
+            return r'(?P<{}>.*?)'.format(field_name)
         if '%' in format_spec:
             return r'(?P<{}>{})'.format(field_name, self._regex_datetime(format_spec))
         return self.format_spec_to_regex(field_name, format_spec)
